#ifndef NT2_INCLUDE_CONSTANTS_HUNDRED_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_HUNDRED_HPP_INCLUDED

#include <nt2/constant/include/constants/hundred.hpp>

#endif
